@@ -8,6 +8,7 @@ from pynsee.utils import clear_all_cache
 clear_all_cache()
 
 def run():
+    clear_all_cache()
     app = FastMCP("insee-server")
     @app.tool()
     async def search_company(
@@ -29,12 +30,12 @@ def run():
             dict: Informations clés sur l'entreprise.
         """
         print("API KEY inside server:", os.getenv("API_KEY"))
+        init_conn(sirene_key=os.getenv("API_KEY"))
         return search_sirene_company(company_name, siren, siret, fuzzy)
 
-    # Lancement du serveur avec transport streamable-http
-    app.run(transport="streamable-http", host="127.0.0.1", port=9000, path="/mcp")
+    # Lancement du serveur avec transport stdio
+    # app.run(transport="stdio", host="127.0.0.1", port=8000, path="/mcp")
+    app.run(transport="stdio")
 
 if __name__ == "__main__":
-    
-    print("API_KEY:", os.getenv("API_KEY"))
     run()
